@@ -30,16 +30,24 @@ class VaultService(CrudService[VaultRepository, VaultEntry]):
         super().__init__(VaultRepository(vault_config))
 
     def get_by_key(self, key: str) -> Optional[VaultEntry]:
-        """Get aa vault entry using the specified key
+        """Get a vault entry using the specified key
         :param key: The vault key to find
         """
         return self.repository.find_by_key(key)
 
+    def exists(self, key: str) -> bool:
+        """Return whether the key exists or not in the database
+        :param key: The vault key to check
+        """
+        return self.repository.exists(key)
+
     def list_by_key(self, filter_expr: List[str] = None) -> List[VaultEntry]:
+        """TODO"""
         filters = " or ".join([f"key like '%{f}%'" for f in filter_expr])
         return self.list(Namespace("Filters", by_key_like=filters), ["key", "modified"])
 
     def create_vault_db(self) -> None:
+        """TODO"""
         self.repository.execute(
             dedent(
                 """
