@@ -15,7 +15,7 @@
 import re
 from collections import namedtuple
 from textwrap import dedent
-from typing import Union
+from typing import Union, Optional
 
 from clitt.core.tui.minput.input_validator import InputValidator
 from clitt.core.tui.minput.minput import MenuInput, minput
@@ -41,7 +41,7 @@ class VaultEntry(CrudEntity):
     )
 
     @staticmethod
-    def prompt(existing_entry: Union['VaultEntry', None] = None) -> 'VaultEntry':
+    def prompt(existing_entry: Union['VaultEntry', None] = None) -> Optional['VaultEntry']:
         """Create a vault entry from a form input"""
         entry = existing_entry or VaultEntry()
         # fmt: off
@@ -75,7 +75,8 @@ class VaultEntry(CrudEntity):
             entry.hint = result.hint
             entry.password = result.password
             entry.modified = now()
-        return entry
+
+        return entry if result else None
 
     def __init__(
         self, entity_id: Identity = VaultId(Identity.auto().values),
